==> pymetrick-0.41.zip: pymetrick-0.41/pymetrick/mail.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Modulo para gestionar mail"""

__author__ = 'Fco.Javier Tamarit V <javtamvi@gmail.com>'
__copyright__ = "Copyright (C) 2012 PYMETRICK.ORG"
__date__ = '2014-05-21'
__version__ = '0.4'
__license__ = 'Licencia GNU/GPLv2'
__credits__ = ''
__text__ = 'Gestion de funciones para Mail'
__file__ = 'mail.py'

#--- CHANGES ------------------------------------------------------------------
# 2015-05-04 v0.01 PL: - First version

import sys
import os
import logging
from smtplib import SMTP, SMTP_SSL                  # use this for standard SMTP protocol   (port 25, no encryption or port 465, uses SSL)
import imaplib
from email.MIMEMultipart import MIMEMultipart
from email.MIMEBase import MIMEBase
from email.MIMEText import MIMEText
from email.MIMEImage import MIMEImage
from email.Utils import COMMASPACE, formatdate
from email import Encoders

from datetime import datetime, timedelta, tzinfo
from helpers import *

# Version PY
PY2 = True if sys.version[:1] == '2' else False;
PY3 = True if sys.version[:1] == '3' else False;

# En Python 3  long = int
if PY3:
    long = int

# Comprobar codigo en desarrollo
DEBUG = False

# Send an HTML email with an embedded image and a plain text message for
# email clients that don't want to display the HTML.

def sendmail(from_addr=None, to_addr_list=[], cc_addr_list=[], bcc_addr_list=[],
              subject=None, message=None, message_html=None,
              login=None, password=None,
              smtpserver=None, port=None):

    # for standard SMTP protocol port 25, no encryption
    # for standard SMTP protocol port 465, SSL
    # for standard SMTP protocol port 587, TLS

    #Tratamiento de errores en LOG
    __name__ = "mail.sendmail"
    sys.stdout = sys.stderr

    if DEBUG:
        logPath = ''
        logging.basicConfig(stream=sys.stderr, level=logging.DEBUG)
        LOG = logging.getLogger(__name__)
        hdlr = logging.FileHandler(logPath+__name__+'.log')
        formatter = logging.Formatter('%(asctime)s %(levelname)s %(message)s')
        hdlr.setFormatter(formatter)
        LOG.addHandler(hdlr)
        LOG.info("Session modo local INICIO")
    else:
        logging.basicConfig(stream=sys.stderr, level=logging.DEBUG)
        LOG = logging.getLogger(__name__)

    try:

        # Create the root message and fill in the from, to, and subject headers
        msgRoot = MIMEMultipart('related')
        msgRoot['Subject'] = string2unicode(subject)
        msgRoot['From'] = string2unicode(from_addr)
        if type(to_addr_list).__name__ == 'list':
            for n in to_addr_list:
                to_addr_list[n] = str2unicode(to_addr_list[n])
        else:
            to_addr_list = [str2unicode(to_addr_list)]
        msgRoot['To'] = ",".join(to_addr_list)
        if cc_addr_list is not None:
            if type(cc_addr_list).__name__ == 'list':
                for n in cc_addr_list:
                    cc_addr_list[n] = str2unicode(cc_addr_list[n])
            else:
                cc_addr_list = [str2unicode(cc_addr_list)]
            msgRoot['Cc'] = ','.join(cc_addr_list)
        if bcc_addr_list is not None:
            if type(bcc_addr_list).__name__ == 'list':
                for n in bcc_addr_list:
                    bcc_addr_list[n] = str2unicode(bcc_addr_list[n])
            else:
                bcc_addr_list = [str2unicode(bcc_addr_list)]
            msgRoot['Bcc'] = ','.join(bcc_addr_list)
        lstTo = bcc_addr_list+cc_addr_list+to_addr_list
        #msgRoot['Date'] = timeZone('Madrid').strftime( "%m/%d/%Y %H:%M" )
        msgRoot.preamble = 'This is a multi-part message in MIME format.'

        # Encapsulate the plain and HTML versions of the message body in an
        # 'alternative' part, so message agents can decide which they want to display.
        msgAlternative = MIMEMultipart('alternative')
        msgRoot.attach(msgAlternative)
        # mensaje con texto plano
        # MIMEText(_text[, _subtype[, _charset]])
        msgText = MIMEText(string2unicode(message), _subtype='plain',_charset='utf-8')
        # msgText.set_param(charset, 'UTF-8')
        msgAlternative.attach(msgText)
        # mensaje en formato html
        # MIMEText(_text[, _subtype[, _charset]])
        msgText = MIMEText(latin2html(message_html), _subtype='html',_charset='utf-8')
        # msgText.set_param(charset, 'UTF-8')
        msgAlternative.attach(msgText)

        # Ejemplo de como introducir una imagen en el texto html
        #'<b>Some <i>HTML</i> text</b> and an image.<br><img src="cid:image1"><br>Nifty!'

        # We reference the image in the IMG SRC attribute by the ID we give it below
        # This example assumes the image is in the current directory
        #fp = open('test.jpg', 'rb')
        #msgImage = MIMEImage(fp.read())
        #fp.close()

        # Define the image's ID as referenced above
        #msgImage.add_header('Content-ID', '<image1>')
        #msgRoot.attach(msgImage)


        #logging.debug("Attempting to send email via %s:%i using the following credentials (%s:%s)." % (server, port, username, password))


        # Send the email (this example assumes SMTP authentication is required)
        if port==465:
            server = SMTP_SSL()
        else:
            server = SMTP()
        server.set_debuglevel(True) # show communication with the server
        server.connect(smtpserver, port)
        server.ehlo()
        if server.has_extn('STARTTLS') and port==587:
            server.starttls()
            server.ehlo()   # re-identify ourselves over TLS connection
        server.login(login, password)
        try:
            server.sendmail(from_addr, lstTo, msgRoot.as_string())
            return '200'
        except Exception, e:
            tb = sys.exc_info()[2]
            LOG.error('Error <envio de mail> <%s> en linea %s !!!' % (str(e),tb.tb_lineno))
            return '401'
        finally:
            server.quit()
    except Exception,e:
        tb = sys.exc_info()[2]
        LOG.error('Error <%s> en linea %s !!!' % (str(e),tb.tb_lineno))



def emptyIMAP():
    """Eliminar todos los correos de IMAP"""

    M = imaplib.IMAP4('mail.webfaction.com')
    M.login('<mailbox_name>', '<mailbox_password>')
    M.select('<folder>')
    typ, data = M.search(None, 'ALL')
    for msgid in data[0].split():
        M.store(msgid, '+FLAGS', '(\\Deleted)')
    M.expunge()
    M.close()
    M.logout()

def timeZone(timeZone):
    """Adaptar la hora segun la zona horaria"""
    zone = {'Madrid':2,'Londres':1,'Kabul':4.5}
    nowUTC = datetime.utcnow()
    return nowUTC + timedelta(hours=zone[timeZone])

if __name__ == "__main__":
    if len(sys.argv) < 2:
        sys.stderr.write("for help use -h o --help")
    elif sys.argv[1]=='-h' or sys.argv[1]=='--help':
        print (u'''
        Podra enviar fácilmente mensajes de correo electronico :

        ''')

==> pymetrick-0.42.zip: pymetrick-0.42/pymetrick/mail.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Modulo para gestionar mail"""

from pymetrick import version
__author__ = version.__author__
__copyright__ = version.__copyright__
__license__ = version.__license__
__version__ = version.__version__
__date__ = '2014-05-21'
__credits__ = ''
__text__ = 'Gestion de funciones para Mail'
__file__ = 'mail.py'

#--- CHANGES ------------------------------------------------------------------
# 2015-05-04 v0.01 PL: - First version

import sys
import os
import mimetypes
import logging
from smtplib import SMTP, SMTP_SSL                  # use this for standard SMTP protocol   (port 25, no encryption or port 465, uses SSL)
from imaplib import IMAP4

try:
    from email.MIMEMultipart import MIMEMultipart
    from email.MIMEBase import MIMEBase
    from email.MIMEText import MIMEText
    from email.MIMEImage import MIMEImage
    from email.MIMEAudio import MIMEAudio
    from email.Utils import COMMASPACE, formatdate
    from email import Encoders

except ImportError:
    # Python 3
    from email.mime.audio import MIMEAudio
    from email.mime.base import MIMEBase
    from email.mime.image import MIMEImage
    from email.mime.multipart import MIMEMultipart
    from email.mime.text import MIMEText
    from email import encoders

from datetime import datetime, timedelta, tzinfo
from pymetrick.helpers import *

# Version PY
PY2 = True if sys.version[:1] == '2' else False;
PY3 = True if sys.version[:1] == '3' else False;

# En Python 3  long = int
if PY3:
    long = int

# Comprobar codigo en desarrollo
DEBUG = False

# Send an HTML email with an embedded image and a plain text message for
# email clients that don't want to display the HTML.

def sendmail(from_addr=None, to_addr_list=[], cc_addr_list=[], bcc_addr_list=[],
              subject=None, message=None, message_html=None,
              login=None, password=None,
              smtpserver=None, port=None):

    # for standard SMTP protocol port 25, no encryption
    # for standard SMTP protocol port 465, SSL
    # for standard SMTP protocol port 587, TLS

    #Tratamiento de errores en LOG
    __name__ = "mail.sendmail"
    sys.stdout = sys.stderr

    if DEBUG:
        logPath = ''
        if len(logPath)>0:
            lobPath += os.sep
        logging.basicConfig(stream=sys.stderr, level=logging.DEBUG)
        LOG = logging.getLogger(__name__)
        hdlr = logging.FileHandler(logPath+__name__+'.log')
        formatter = logging.Formatter('%(asctime)s %(levelname)s %(message)s')
        hdlr.setFormatter(formatter)
        LOG.addHandler(hdlr)
        LOG.info("Mail modo local INICIO")
    else:
        logging.basicConfig(stream=sys.stderr, level=logging.DEBUG)
        LOG = logging.getLogger(__name__)

    try:

        # Create the root message and fill in the from, to, and subject headers
        msgRoot = MIMEMultipart('related')
        msgRoot['Subject'] = string2unicode(subject)
        msgRoot['From'] = string2unicode(from_addr)
        if type(to_addr_list).__name__ == 'list':
            for n in to_addr_list:
                to_addr_list[n] = str2unicode(to_addr_list[n])
        else:
            to_addr_list = [str2unicode(to_addr_list)]
        msgRoot['To'] = ",".join(to_addr_list)
        if cc_addr_list is not None:
            if type(cc_addr_list).__name__ == 'list':
                for n in cc_addr_list:
                    cc_addr_list[n] = str2unicode(cc_addr_list[n])
            else:
                cc_addr_list = [str2unicode(cc_addr_list)]
            msgRoot['Cc'] = ','.join(cc_addr_list)
        if bcc_addr_list is not None:
            if type(bcc_addr_list).__name__ == 'list':
                for n in bcc_addr_list:
                    bcc_addr_list[n] = str2unicode(bcc_addr_list[n])
            else:
                bcc_addr_list = [str2unicode(bcc_addr_list)]
            msgRoot['Bcc'] = ','.join(bcc_addr_list)
        lstTo = bcc_addr_list+cc_addr_list+to_addr_list
        #msgRoot['Date'] = timeZone('Madrid').strftime( "%m/%d/%Y %H:%M" )
        msgRoot.preamble = 'This is a multi-part message in MIME format.'

        # Encapsulate the plain and HTML versions of the message body in an
        # 'alternative' part, so message agents can decide which they want to display.
        msgAlternative = MIMEMultipart('alternative')
        msgRoot.attach(msgAlternative)
        # mensaje con texto plano
        # MIMEText(_text[, _subtype[, _charset]])
        msgText = MIMEText(string2unicode(message), _subtype='plain',_charset='utf-8')
        # msgText.set_param(charset, 'UTF-8')
        msgAlternative.attach(msgText)
        # mensaje en formato html
        # MIMEText(_text[, _subtype[, _charset]])
        msgText = MIMEText(latin2html(message_html), _subtype='html',_charset='utf-8')
        # msgText.set_param(charset, 'UTF-8')
        msgAlternative.attach(msgText)

        # Ejemplo de como introducir una imagen en el texto html
        #'<b>Some <i>HTML</i> text</b> and an image.<br><img src="cid:image1"><br>Nifty!'

        # We reference the image in the IMG SRC attribute by the ID we give it below
        # This example assumes the image is in the current directory
        #fp = open('test.jpg', 'rb')
        #msgImage = MIMEImage(fp.read())
        #fp.close()

        # Define the image's ID as referenced above
        #msgImage.add_header('Content-ID', '<image1>')
        #msgRoot.attach(msgImage)


        #logging.debug("Attempting to send email via %s:%i using the following credentials (%s:%s)." % (server, port, username, password))


        # Send the email (this example assumes SMTP authentication is required)
        if port==465:
            server = SMTP_SSL()
        else:
            server = SMTP()
        server.set_debuglevel(True) # show communication with the server
        server.connect(smtpserver, port)
        server.ehlo()
        if server.has_extn('STARTTLS') and port==587:
            server.starttls()
            server.ehlo()   # re-identify ourselves over TLS connection
        server.login(login, password)
        try:
            server.sendmail(from_addr, lstTo, msgRoot.as_string())
            return '200'
        except Exception as e:
            tb = sys.exc_info()[2]
            LOG.error('Error <envio de mail> <%s> en linea %s !!!' % (str(e),tb.tb_lineno))
            return '401'
        finally:
            server.quit()
    except Exception as e:
        tb = sys.exc_info()[2]
        LOG.error('Error <%s> en linea %s !!!' % (str(e),tb.tb_lineno))

def add_annex(msg, filename):

    #Tratamiento de errores en LOG
    __name__ = "mail.add_annex"
    sys.stdout = sys.stderr

    if DEBUG:
        logPath = ''
        if len(logPath)>0:
            lobPath += os.sep
        logging.basicConfig(stream=sys.stderr, level=logging.DEBUG)
        LOG = logging.getLogger(__name__)
        hdlr = logging.FileHandler(logPath+__name__+'.log')
        formatter = logging.Formatter('%(asctime)s %(levelname)s %(message)s')
        hdlr.setFormatter(formatter)
        LOG.addHandler(hdlr)
        LOG.info("Mail modo local INICIO")
    else:
        logging.basicConfig(stream=sys.stderr, level=logging.DEBUG)
        LOG = logging.getLogger(__name__)
    try:

        if not os.path.isfile(filename):
            return

        ctype, encoding = mimetypes.guess_type(filename)

        if ctype is None or encoding is not None:
            ctype = 'application/octet-stream'

        maintype, subtype = ctype.split('/', 1)

        if maintype == 'text':
            with open(filename) as f:
                mime = MIMEText(f.read(), _subtype=subtype)
        elif maintype == 'image':
            with open(filename, 'rb') as f:
                mime = MIMEImage(f.read(), _subtype=subtype)
        elif maintype == 'audio':
            with open(filename, 'rb') as f:
                mime = MIMEAudio(f.read(), _subtype=subtype)
        else:
            with open(filename, 'rb') as f:
                mime = MIMEBase(maintype, subtype)
                mime.set_payload(f.read())

            encoders.encode_base64(mime)

        mime.add_header('Content-Disposition', 'attachment', filename=filename)
        msg.attach(mime)
    except Exception as e:
        tb = sys.exc_info()[2]
        LOG.error('Error <%s> en linea %s !!!' % (str(e),tb.tb_lineno))
def emptyIMAP():
    """Eliminar todos los correos de IMAP"""

    M = IMAP4('mail.webfaction.com')
    M.login('<mailbox_name>', '<mailbox_password>')
    M.select('<folder>')
    typ, data = M.search(None, 'ALL')
    for msgid in data[0].split():
        M.store(msgid, '+FLAGS', '(\\Deleted)')
    M.expunge()
    M.close()
    M.logout()

def timeZone(timeZone):
    """Adaptar la hora segun la zona horaria"""
    zone = {'Madrid':2,'Londres':1,'Kabul':4.5}
    nowUTC = datetime.utcnow()
    return nowUTC + timedelta(hours=zone[timeZone])

if __name__ == "__main__":
    if len(sys.argv) < 2:
        sys.stderr.write("for help use -h o --help")
    elif sys.argv[1]=='-h' or sys.argv[1]=='--help':
        print (u'''version {0}'''.format( __version__))
        print (u'''
        Podra enviar fácilmente mensajes de correo electronico :

        ''')
    # prueba de envio de mail
    sendmail(from_addr='pymetrick@pymetrick.org',to_addr_list='javtamvi@gmail.com',subject=u'Asunto Prueba de envio de mail',message=u'esto es una prueba de texto',message_html=u'<div>Esto es una prueba html</div>',login='pymetrick',password='BETACA96',smtpserver='smtp.webfaction.com',port=25)

    """now = datetime.now()
    nowUTC = datetime.utcnow()

    print ("UTC: ", nowUTC)
    print ("Today: ", now)
    print ("Yesterday: ", now - timedelta(hours=1))
    print (timeZone('Madrid'))
    print (timeZone('Kabul'))
    print (timeZone('Madrid').strftime( "%m/%d/%Y %H:%M" ))"""
